<?php
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
/**#@-*/

require_once('../wp-includes/compat.php');
require_once('../wp-includes/functions.php');
require_once('../wp-includes/classes.php');

if (!file_exists('../wp-config-sample.php'))
	wp_die('Sorry, I need a wp-config-sample.php file to work from. Please re-upload this file from your WordPress installation.');

$configFile = file('../wp-config-sample.php');

if ( !is_writable('../'))
	wp_die("Sorry, I can't write to the directory. You'll have to either change the permissions on your WordPress directory or create your wp-config.php manually.");

// Check if wp-config.php has been created
if (file_exists('../wp-config.php'))
	wp_die("<p>Soubor 'wp-config.php' již existuje. Pokud potřebujete upravit některé údaje v souboru <code>wp-config.php</code>, smažte jej nebo editujte ručně. Nebo nyní můžete <a href='install.php'>Spustit instalaci</a>.</p>");

// Check if wp-config.php exists above the root directory
if (file_exists('../../wp-config.php') && ! file_exists('../../wp-load.php'))
	wp_die("<p>The file 'wp-config.php' already exists one level above your WordPress installation. If you need to reset any of the configuration items in this file, please delete it first. You may try <a href='install.php'>installing now</a>.</p>");

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>WordPress &rsaquo; Instalace - vytvoření konfiguračního souboru</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />

</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>Vítejte v instalaci WordPress. Než budete pokračovat, ujistěte se, že znáte následující informace o vaší databazi. Bez nich nebude možné v instalaci pokračovat!</p>
<ol>
	<li>Název databáze</li>
	<li>Uživatelské jméno pro přihlášení do databáze</li>
	<li>Heslo pro přihlášení do databáze</li>
	<li>Název nebo IP adresu DB serveru</li>
	<li>Předpona databáze (v případě, že sdílíte jednu databázi s více než jednou instalací WordPress) </li>
</ol>

<p><strong>Pokud z jakéhokoliv důvodu automatické vytváření souborů nefunguje, nezoufejte. Stačí jednoduše otevřít soubor <code>wp-config-sample.php</code> v textovém editoru ( např. poznámkový blok nebo PSPad ) a dopnit potřebné informace ručně. Tento soubor následně uložte jako <code>wp-config.php</code>. </strong></p>
<p>Informace o databázi jste s největší pravděpodobností získali při zřizování webhostingu od poskytovatele webhostingových služeb. Pokud tyto informace nemáte, získejte je od poskytovatele hostingu. Pokud jste připraveni&hellip;</p>

<p class="step"><a href="setup-config.php?step=1" class="button">Pokračovat!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>Níže je třeba zadat informace o databázi. Pokud si nejste některou z nich jisti, obraťte se na poskytovatele webhostingu..</p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">Název databáze</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>Název databáze na které bude WordPress běžet. </td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">Uživatelské jméno</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="username" /></td>
			<td>Uživatelské jméno pro přístup k Databázi.</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">Heslo</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
			<td>Heslo k uživatelskému jménu.</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">Adresa DB serveru</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td>V 99% případu to býva localhost.</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">Předpona tabulek</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>Předponu upravte pouze v případě, že na jedné databazi budete provozovat více instalací WordPress.</td>
		</tr>
	</table>
	<p class="step"><input name="submit" type="submit" value="Pokračuj" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if (empty($prefix)) $prefix = 'wp_';

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( !empty($wpdb->error) )
		wp_die($wpdb->error->get_error_message());

	$handle = fopen('../wp-config.php', 'w');

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				fwrite($handle, str_replace("putyourdbnamehere", $dbname, $line));
				break;
			case "define('DB_USER'":
				fwrite($handle, str_replace("'usernamehere'", "'$uname'", $line));
				break;
			case "define('DB_PASSW":
				fwrite($handle, str_replace("'yourpasswordhere'", "'$passwrd'", $line));
				break;
			case "define('DB_HOST'":
				fwrite($handle, str_replace("localhost", $dbhost, $line));
				break;
			case '$table_prefix  =':
				fwrite($handle, str_replace('wp_', $prefix, $line));
				break;
			default:
				fwrite($handle, $line);
		}
	}
	fclose($handle);
	chmod('../wp-config.php', 0666);

	display_header();
?>
<p>Výborně! Všechny zadané informace jsou v pořádku. WordPress nyní může komunikovat s vaší databázi. Jste-li připraveni, je čas&hellip;</p>

<p class="step"><a href="install.php" class="button">Spustit instalaci!</a></p>
<?php
	break;
}
?>
</body>
</html>
